leaftools.fuse_leaves_in_container_once_by_counts_into_little_endian_rests
==========================================================================

.. autofunction:: abjad.tools.leaftools.fuse_leaves_in_container_once_by_counts_into_little_endian_rests.fuse_leaves_in_container_once_by_counts_into_little_endian_rests
